summaryrefslogtreecommitdiffstats
path: root/kshowmail
diff options
context:
space:
mode:
authorTimothy Pearson <kb9vqf@pearsoncomputing.net>2013-08-27 23:14:23 -0500
committerTimothy Pearson <kb9vqf@pearsoncomputing.net>2013-08-27 23:14:23 -0500
commit53f0e03201d2229361f4748f9d3240c552074008 (patch)
treecf5ab34221293cb52b867a3b85d8fcfb60e1c805 /kshowmail
parent93eccb95f73281d01de59616fa6dfb88700b7dc5 (diff)
downloadkshowmail-53f0e03201d2229361f4748f9d3240c552074008.tar.gz
kshowmail-53f0e03201d2229361f4748f9d3240c552074008.zip
Rename KWallet to TDEWallet
Diffstat (limited to 'kshowmail')
-rw-r--r--kshowmail/configelem.cpp6
-rw-r--r--kshowmail/configlist.cpp2
-rw-r--r--kshowmail/constants.h2
-rw-r--r--kshowmail/kcmconfigs/accountsetupdialog.cpp8
-rw-r--r--kshowmail/kcmconfigs/accountsetupitem.cpp6
-rw-r--r--kshowmail/kcmconfigs/tdewalletaccess.cpp50
-rw-r--r--kshowmail/kcmconfigs/tdewalletaccess.h8
-rw-r--r--kshowmail/serverdialog.cpp10
-rw-r--r--kshowmail/tdewalletaccess.cpp50
-rw-r--r--kshowmail/tdewalletaccess.h8
10 files changed, 75 insertions, 75 deletions
diff --git a/kshowmail/configlist.cpp b/kshowmail/configlist.cpp
index c435d01..58bb90a 100644
--- a/kshowmail/configlist.cpp
+++ b/kshowmail/configlist.cpp
@@ -888,7 +888,7 @@ void ConfigList::refreshSetup( TDEListView* view )
case CONFIG_VALUE_ACCOUNT_PASSWORD_SAVE_KWALLET:
acc->setPasswordStorage( CONFIG_VALUE_ACCOUNT_PASSWORD_SAVE_KWALLET );
- acc->setPassword( KWalletAccess::getPassword( *it ) );
+ acc->setPassword( TDEWalletAccess::getPassword( *it ) );
break;
default:
diff --git a/kshowmail/constants.h b/kshowmail/constants.h
index fe91a2a..b36a36f 100644
--- a/kshowmail/constants.h
+++ b/kshowmail/constants.h
@@ -101,7 +101,7 @@ namespace Constants
#define DEFAULT_ACCOUNT_USER ""
#define DEFAULT_ACCOUNT_PASSWORD ""
#define DEFAULT_ACCOUNT_PASSWORD_STORAGE 1
- //1: don't save, 2: save in file, 3: use KWallet
+ //1: don't save, 2: save in file, 3: use TDEWallet
#define DEFAULT_ACCOUNT_ACTIVE true
#define DEFAULT_ACCOUNT_SECTRANSFER 1
//1: no secure transfer, 2: SSL, 3: TLS
diff --git a/kshowmail/kcmconfigs/accountsetupdialog.cpp b/kshowmail/kcmconfigs/accountsetupdialog.cpp
index dc800ee..9e48369 100644
--- a/kshowmail/kcmconfigs/accountsetupdialog.cpp
+++ b/kshowmail/kcmconfigs/accountsetupdialog.cpp
@@ -88,16 +88,16 @@ AccountSetupDialog::AccountSetupDialog( TQWidget* parent, TDEListView* view, Acc
TQRadioButton* btnPasswordDontSave = new TQRadioButton( i18n( "Don't save" ), gboxPassword, "btnPasswordDontSave" );
TQRadioButton* btnPasswordSaveFile = new TQRadioButton( i18n( "Save password"), gboxPassword, "btnPasswordSaveFile" );
- TQRadioButton* btnPasswordSaveKWallet = new TQRadioButton( i18n( "Use KWallet" ), gboxPassword, "btnPasswordSaveKWallet" );
+ TQRadioButton* btnPasswordSaveTDEWallet = new TQRadioButton( i18n( "Use TDEWallet" ), gboxPassword, "btnPasswordSaveTDEWallet" );
grpPasswordStorage->insert( btnPasswordDontSave, ID_BUTTON_PASSWORD_DONT_SAVE );
grpPasswordStorage->insert( btnPasswordSaveFile, ID_BUTTON_PASSWORD_SAVE_FILE );
- grpPasswordStorage->insert( btnPasswordSaveKWallet, ID_BUTTON_PASSWORD_SAVE_KWALLET );
+ grpPasswordStorage->insert( btnPasswordSaveTDEWallet, ID_BUTTON_PASSWORD_SAVE_KWALLET );
TQToolTip::add( btnPasswordDontSave, i18n( "Don't save password. KShowmail will ask you for it at first server connect." ) );
TQToolTip::add( btnPasswordSaveFile, i18n( "Save password in the configuration file. Not recommended, because the password is just lightly encrypted" ) );
- TQToolTip::add( btnPasswordSaveKWallet, i18n( "Use KWallet to save the password. Maybe you have to type in the KWallet master password at first server connect." ) );
+ TQToolTip::add( btnPasswordSaveTDEWallet, i18n( "Use TDEWallet to save the password. Maybe you have to type in the TDEWallet master password at first server connect." ) );
layPasswordStorage->addWidget( btnPasswordDontSave, 0, 0 );
layPasswordStorage->addWidget( btnPasswordSaveFile, 0, 1 );
- layPasswordStorage->addWidget( btnPasswordSaveKWallet, 1, 0 );
+ layPasswordStorage->addWidget( btnPasswordSaveTDEWallet, 1, 0 );
//password edit line
txtPassword = new KPasswordEdit( gboxPassword, "txtUser" );
diff --git a/kshowmail/serverdialog.cpp b/kshowmail/serverdialog.cpp
index 9d7ad94..3c0c7d9 100644
--- a/kshowmail/serverdialog.cpp
+++ b/kshowmail/serverdialog.cpp
@@ -94,16 +94,16 @@ ServerDialog::ServerDialog( TQWidget* parent, ConfigElem* item )
TQRadioButton* btnPasswordDontSave = new TQRadioButton( i18n( "Don't save" ), gboxPassword, "btnPasswordDontSave" );
TQRadioButton* btnPasswordSaveFile = new TQRadioButton( i18n( "Save password"), gboxPassword, "btnPasswordSaveFile" );
- TQRadioButton* btnPasswordSaveKWallet = new TQRadioButton( i18n( "Use KWallet" ), gboxPassword, "btnPasswordSaveKWallet" );
+ TQRadioButton* btnPasswordSaveTDEWallet = new TQRadioButton( i18n( "Use TDEWallet" ), gboxPassword, "btnPasswordSaveTDEWallet" );
grpPasswordStorage->insert( btnPasswordDontSave, ID_BUTTON_PASSWORD_DONT_SAVE );
grpPasswordStorage->insert( btnPasswordSaveFile, ID_BUTTON_PASSWORD_SAVE_FILE );
- grpPasswordStorage->insert( btnPasswordSaveKWallet, ID_BUTTON_PASSWORD_SAVE_KWALLET );
+ grpPasswordStorage->insert( btnPasswordSaveTDEWallet, ID_BUTTON_PASSWORD_SAVE_KWALLET );
TQToolTip::add( btnPasswordDontSave, i18n( "Don't save password. KShowmail will ask you for it at first server connect." ) );
TQToolTip::add( btnPasswordSaveFile, i18n( "Save password in the configuration file. Not recommended, because the password is just lightly encrypted" ) );
- TQToolTip::add( btnPasswordSaveKWallet, i18n( "Use KWallet to save the password. Maybe you have to type in the KWallet master password at first server connect." ) );
+ TQToolTip::add( btnPasswordSaveTDEWallet, i18n( "Use TDEWallet to save the password. Maybe you have to type in the TDEWallet master password at first server connect." ) );
layPasswordStorage->addWidget( btnPasswordDontSave, 0, 0 );
layPasswordStorage->addWidget( btnPasswordSaveFile, 0, 1 );
- layPasswordStorage->addWidget( btnPasswordSaveKWallet, 1, 0 );
+ layPasswordStorage->addWidget( btnPasswordSaveTDEWallet, 1, 0 );
//password edit line
txtPassword = new KPasswordEdit( gboxPassword, "txtUser" );
@@ -239,7 +239,7 @@ void ServerDialog::slotOk( )
break;
case ID_BUTTON_PASSWORD_SAVE_KWALLET : config->writeEntry( CONFIG_ENTRY_ACCOUNT_PASSWORD_STORAGE, CONFIG_VALUE_ACCOUNT_PASSWORD_SAVE_KWALLET );
config->writeEntry( CONFIG_ENTRY_ACCOUNT_PASSWORD, TQString::null );
- KWalletAccess::savePassword( txtAccount->text(), pass );
+ TDEWalletAccess::savePassword( txtAccount->text(), pass );
break;
default : config->writeEntry( CONFIG_ENTRY_ACCOUNT_PASSWORD_STORAGE, CONFIG_VALUE_ACCOUNT_PASSWORD_DONT_SAVE );
config->writeEntry( CONFIG_ENTRY_ACCOUNT_PASSWORD, TQString::null );
diff --git a/kshowmail/configelem.cpp b/kshowmail/configelem.cpp
index 356e726..43b11b5 100644
--- a/kshowmail/configelem.cpp
+++ b/kshowmail/configelem.cpp
@@ -303,7 +303,7 @@ bool ConfigElem::assertPassword( bool force )
//store the password
setPassword( password );
//save password in file or KWallet
TDEConfig* config = TDEApplication::kApplication()->config();
config->setGroup( getAccountName() );
@@ -313,7 +313,7 @@ bool ConfigElem::assertPassword( bool force )
config->writeEntry( CONFIG_ENTRY_ACCOUNT_PASSWORD, TQString::null );
if( PasswordStorage == CONFIG_VALUE_ACCOUNT_PASSWORD_SAVE_KWALLET )
- KWalletAccess::savePassword( getAccountName(), m_url.pass() );
+ TDEWalletAccess::savePassword( getAccountName(), m_url.pass() );
config->sync();
@@ -1211,7 +1211,7 @@ void ConfigElem::printSetup( ) const
{
case CONFIG_VALUE_ACCOUNT_PASSWORD_DONT_SAVE : kdDebug() << "Password Storage: don't save" << endl; break;
case CONFIG_VALUE_ACCOUNT_PASSWORD_SAVE_FILE : kdDebug() << "Password Storage: save in file" << endl; break;
- case CONFIG_VALUE_ACCOUNT_PASSWORD_SAVE_KWALLET : kdDebug() << "Password Storage: use KWallet" << endl; break;
+ case CONFIG_VALUE_ACCOUNT_PASSWORD_SAVE_KWALLET : kdDebug() << "Password Storage: use TDEWallet" << endl; break;
default : kdDebug() << "Password Storage: invalid value" << endl;
}
@@ -303,7 +303,7 @@ bool ConfigElem::assertPassword( bool force )
//store the password
setPassword( password );
- //save password in file or KWallet
+ //save password in file or TDEWallet
TDEConfig* config = TDEApplication::kApplication()->config();
config->setGroup( getAccountName() );
diff --git a/kshowmail/kcmconfigs/accountsetupitem.cpp b/kshowmail/kcmconfigs/accountsetupitem.cpp
index d7846fe..6ca8ad4 100644
--- a/kshowmail/kcmconfigs/accountsetupitem.cpp
+++ b/kshowmail/kcmconfigs/accountsetupitem.cpp
@@ -159,9 +159,9 @@ void AccountSetupItem::save() const
else
config->writeEntry( CONFIG_ENTRY_ACCOUNT_PASSWORD, TQString::null );
//save password in KWallet if desired
if( getPasswordStorageType() == CONFIG_VALUE_ACCOUNT_PASSWORD_SAVE_KWALLET )
- KWalletAccess::savePassword( getAccountName(), getPassword() );
+ TDEWalletAccess::savePassword( getAccountName(), getPassword() );
config->writeEntry( CONFIG_ENTRY_ACCOUNT_ACTIVE, getActive() );
config->writeEntry( CONFIG_ENTRY_ACCOUNT_SECTRANSFER, getTransferSecurity() );
@@ -181,7 +181,7 @@ void AccountSetupItem::load( )
if( _passwordStorage == CONFIG_VALUE_ACCOUNT_PASSWORD_SAVE_FILE )
_password = decrypt( config->readEntry( CONFIG_ENTRY_ACCOUNT_PASSWORD, DEFAULT_ACCOUNT_PASSWORD ) );
else if( _passwordStorage == CONFIG_VALUE_ACCOUNT_PASSWORD_SAVE_KWALLET )
- _password = KWalletAccess::getPassword( getAccountName() );
+ _password = TDEWalletAccess::getPassword( getAccountName() );
else
_password = TQString::null;
@@ -159,9 +159,9 @@ void AccountSetupItem::save() const
else
config->writeEntry( CONFIG_ENTRY_ACCOUNT_PASSWORD, TQString::null );
- //save password in KWallet if desired
+ //save password in TDEWallet if desired
if( getPasswordStorageType() == CONFIG_VALUE_ACCOUNT_PASSWORD_SAVE_KWALLET )
diff --git a/kshowmail/kcmconfigs/tdewalletaccess.cpp b/kshowmail/kcmconfigs/tdewalletaccess.cpp
index 1f48e1c..4aaf5a8 100644
--- a/kshowmail/kcmconfigs/tdewalletaccess.cpp
+++ b/kshowmail/kcmconfigs/tdewalletaccess.cpp
@@ -9,40 +9,40 @@
#include "tdewalletaccess.h"
-bool KWalletAccess::savePassword( const TQString & account, const TQString & password )
+bool TDEWalletAccess::savePassword( const TQString & account, const TQString & password )
{
- //check for enabled KWallet
- if( !KWallet::Wallet::isEnabled() )
+ //check for enabled TDEWallet
+ if( !TDEWallet::Wallet::isEnabled() )
{
- KMessageBox::error( NULL, i18n( "KWallet is not available." ) );
+ KMessageBox::error( NULL, i18n( "TDEWallet is not available." ) );
return false;
}
//get wallet name for network data
- TQString name = KWallet::Wallet::NetworkWallet();
+ TQString name = TDEWallet::Wallet::NetworkWallet();
if( name == "" || name == TQString::null )
{
- KMessageBox::error( NULL, i18n( "Could not get wallet name for network datas from KWallet." ) );
+ KMessageBox::error( NULL, i18n( "Could not get wallet name for network datas from TDEWallet." ) );
return false;
}
//open wallet
//we want to create a connection object just at first call of this function
- static KWallet::Wallet* wallet;
+ static TDEWallet::Wallet* wallet;
if( wallet == NULL )
{
- wallet = KWallet::Wallet::openWallet( name );
+ wallet = TDEWallet::Wallet::openWallet( name );
}
else if( !wallet->isOpen() )
{
delete wallet;
- wallet = KWallet::Wallet::openWallet( name );
+ wallet = TDEWallet::Wallet::openWallet( name );
}
if( wallet == NULL )
{
- KMessageBox::error( NULL, i18n( "Could not open KWallet." ) );
+ KMessageBox::error( NULL, i18n( "Could not open TDEWallet." ) );
return false;
}
@@ -53,7 +53,7 @@ bool KWalletAccess::savePassword( const TQString & account, const TQString & pas
if( !createFolderSuccess )
{
- KMessageBox::error( NULL, i18n( "Could not create folder for KShowmail in KWallet." ) );
+ KMessageBox::error( NULL, i18n( "Could not create folder for KShowmail in TDEWallet." ) );
return false;
}
}
@@ -62,7 +62,7 @@ bool KWalletAccess::savePassword( const TQString & account, const TQString & pas
bool setFolderSuccess = wallet->setFolder( "KShowmail" );
if( !setFolderSuccess )
{
- KMessageBox::error( NULL, i18n( "Could not open folder for KShowmail in KWallet." ) );
+ KMessageBox::error( NULL, i18n( "Could not open folder for KShowmail in TDEWallet." ) );
return false;
}
@@ -70,7 +70,7 @@ bool KWalletAccess::savePassword( const TQString & account, const TQString & pas
int writePasswordSuccess = wallet->writePassword( account, password );
if( writePasswordSuccess != 0 )
{
- KMessageBox::error( NULL, i18n( "Could not save password in KWallet." ) );
+ KMessageBox::error( NULL, i18n( "Could not save password in TDEWallet." ) );
return false;
}
@@ -78,40 +78,40 @@ bool KWalletAccess::savePassword( const TQString & account, const TQString & pas
return true;
}
-TQString KWalletAccess::getPassword( const TQString & account )
+TQString TDEWalletAccess::getPassword( const TQString & account )
{
- //check for enabled KWallet
- if( !KWallet::Wallet::isEnabled() )
+ //check for enabled TDEWallet
+ if( !TDEWallet::Wallet::isEnabled() )
{
- KMessageBox::error( NULL, i18n( "KWallet is not available." ) );
+ KMessageBox::error( NULL, i18n( "TDEWallet is not available." ) );
return TQString::null;
}
//get wallet name for network data
- TQString name = KWallet::Wallet::NetworkWallet();
+ TQString name = TDEWallet::Wallet::NetworkWallet();
if( name == "" || name == TQString::null )
{
- KMessageBox::error( NULL, i18n( "Could not get wallet name for network datas from KWallet." ) );
+ KMessageBox::error( NULL, i18n( "Could not get wallet name for network datas from TDEWallet." ) );
return TQString::null;
}
//open wallet
//we want to create a connection object just at first call of this function
- static KWallet::Wallet* wallet;
+ static TDEWallet::Wallet* wallet;
if( wallet == NULL )
{
- wallet = KWallet::Wallet::openWallet( name );
+ wallet = TDEWallet::Wallet::openWallet( name );
}
else if( !wallet->isOpen() )
{
delete wallet;
- wallet = KWallet::Wallet::openWallet( name );
+ wallet = TDEWallet::Wallet::openWallet( name );
}
if( wallet == NULL )
{
- KMessageBox::error( NULL, i18n( "Could not open KWallet." ) );
+ KMessageBox::error( NULL, i18n( "Could not open TDEWallet." ) );
return TQString::null;
}
@@ -119,7 +119,7 @@ TQString KWalletAccess::getPassword( const TQString & account )
bool setFolderSuccess = wallet->setFolder( "KShowmail" );
if( !setFolderSuccess )
{
- KMessageBox::error( NULL, i18n( "Could not open folder for KShowmail in KWallet." ) );
+ KMessageBox::error( NULL, i18n( "Could not open folder for KShowmail in TDEWallet." ) );
return TQString::null;
}
@@ -129,7 +129,7 @@ TQString KWalletAccess::getPassword( const TQString & account )
int readPasswordSuccess = wallet->readPassword( account, password );
if( readPasswordSuccess != 0 )
{
- KMessageBox::error( NULL, i18n( "Could not get password of account %1 from KWallet." ).arg( account) );
+ KMessageBox::error( NULL, i18n( "Could not get password of account %1 from TDEWallet." ).arg( account) );
return TQString::null;
}
diff --git a/kshowmail/kcmconfigs/tdewalletaccess.h b/kshowmail/kcmconfigs/tdewalletaccess.h
index 905abd9..3bc68d8 100644
--- a/kshowmail/kcmconfigs/tdewalletaccess.h
+++ b/kshowmail/kcmconfigs/tdewalletaccess.h
@@ -19,14 +19,14 @@
#include <tdelocale.h>
/**
* @brief Provides routines to save and read passwords using KWallet.
* @author Ulrich Weigelt <ulrich.weigelt@gmx.de>
*/
-namespace KWalletAccess
+namespace TDEWalletAccess
{
/**
* Saves the given password into KWallet.
* @param account account name
* @param password the password
* @return TRUE - password successfully saved
@@ -37,7 +37,7 @@ namespace KWalletAccess
/**
* Returns the password of the given account.
* @param account account name
* @return the password or TQString::null, if the sought password is not stored in KWallet.
*/
TQString getPassword( const TQString& account );
}
@@ -19,14 +19,14 @@
#include <tdelocale.h>
/**
- * @brief Provides routines to save and read passwords using KWallet.
+ * @brief Provides routines to save and read passwords using TDEWallet.
* @author Ulrich Weigelt <ulrich.weigelt@gmx.de>
*/
@@ -19,14 +19,14 @@
{
/**
- * Saves the given password into KWallet.
+ * Saves the given password into TDEWallet.
* @param account account name
* @param password the password
@@ -37,7 +37,7 @@ namespace KWalletAccess
* Returns the password of the given account.
* @param account account name
- * @return the password or TQString::null, if the sought password is not stored in KWallet.
+ * @return the password or TQString::null, if the sought password is not stored in TDEWallet.
*/
TQString getPassword( const TQString& account );
diff --git a/kshowmail/tdewalletaccess.cpp b/kshowmail/tdewalletaccess.cpp
index 1f48e1c..4aaf5a8 100644
--- a/kshowmail/tdewalletaccess.cpp
+++ b/kshowmail/tdewalletaccess.cpp
@@ -9,40 +9,40 @@
#include "tdewalletaccess.h"
-bool KWalletAccess::savePassword( const TQString & account, const TQString & password )
+bool TDEWalletAccess::savePassword( const TQString & account, const TQString & password )
{
- //check for enabled KWallet
- if( !KWallet::Wallet::isEnabled() )
+ //check for enabled TDEWallet
+ if( !TDEWallet::Wallet::isEnabled() )
{
- KMessageBox::error( NULL, i18n( "KWallet is not available." ) );
+ KMessageBox::error( NULL, i18n( "TDEWallet is not available." ) );
return false;
}
//get wallet name for network data
- TQString name = KWallet::Wallet::NetworkWallet();
+ TQString name = TDEWallet::Wallet::NetworkWallet();
if( name == "" || name == TQString::null )
{
- KMessageBox::error( NULL, i18n( "Could not get wallet name for network datas from KWallet." ) );
+ KMessageBox::error( NULL, i18n( "Could not get wallet name for network datas from TDEWallet." ) );
return false;
}
//open wallet
//we want to create a connection object just at first call of this function
- static KWallet::Wallet* wallet;
+ static TDEWallet::Wallet* wallet;
if( wallet == NULL )
{
- wallet = KWallet::Wallet::openWallet( name );
+ wallet = TDEWallet::Wallet::openWallet( name );
}
else if( !wallet->isOpen() )
{
delete wallet;
- wallet = KWallet::Wallet::openWallet( name );
+ wallet = TDEWallet::Wallet::openWallet( name );
}
if( wallet == NULL )
{
- KMessageBox::error( NULL, i18n( "Could not open KWallet." ) );
+ KMessageBox::error( NULL, i18n( "Could not open TDEWallet." ) );
return false;
}
@@ -53,7 +53,7 @@ bool KWalletAccess::savePassword( const TQString & account, const TQString & pas
if( !createFolderSuccess )
{
- KMessageBox::error( NULL, i18n( "Could not create folder for KShowmail in KWallet." ) );
+ KMessageBox::error( NULL, i18n( "Could not create folder for KShowmail in TDEWallet." ) );
return false;
}
}
@@ -62,7 +62,7 @@ bool KWalletAccess::savePassword( const TQString & account, const TQString & pas
bool setFolderSuccess = wallet->setFolder( "KShowmail" );
if( !setFolderSuccess )
{
- KMessageBox::error( NULL, i18n( "Could not open folder for KShowmail in KWallet." ) );
+ KMessageBox::error( NULL, i18n( "Could not open folder for KShowmail in TDEWallet." ) );
return false;
}
@@ -70,7 +70,7 @@ bool KWalletAccess::savePassword( const TQString & account, const TQString & pas
int writePasswordSuccess = wallet->writePassword( account, password );
if( writePasswordSuccess != 0 )
{
- KMessageBox::error( NULL, i18n( "Could not save password in KWallet." ) );
+ KMessageBox::error( NULL, i18n( "Could not save password in TDEWallet." ) );
return false;
}
@@ -78,40 +78,40 @@ bool KWalletAccess::savePassword( const TQString & account, const TQString & pas
return true;
}
-TQString KWalletAccess::getPassword( const TQString & account )
+TQString TDEWalletAccess::getPassword( const TQString & account )
{
- //check for enabled KWallet
- if( !KWallet::Wallet::isEnabled() )
+ //check for enabled TDEWallet
+ if( !TDEWallet::Wallet::isEnabled() )
{
- KMessageBox::error( NULL, i18n( "KWallet is not available." ) );
+ KMessageBox::error( NULL, i18n( "TDEWallet is not available." ) );
return TQString::null;
}
//get wallet name for network data
- TQString name = KWallet::Wallet::NetworkWallet();
+ TQString name = TDEWallet::Wallet::NetworkWallet();
if( name == "" || name == TQString::null )
{
- KMessageBox::error( NULL, i18n( "Could not get wallet name for network datas from KWallet." ) );
+ KMessageBox::error( NULL, i18n( "Could not get wallet name for network datas from TDEWallet." ) );
return TQString::null;
}
//open wallet
//we want to create a connection object just at first call of this function
- static KWallet::Wallet* wallet;
+ static TDEWallet::Wallet* wallet;
if( wallet == NULL )
{
- wallet = KWallet::Wallet::openWallet( name );
+ wallet = TDEWallet::Wallet::openWallet( name );
}
else if( !wallet->isOpen() )
{
delete wallet;
- wallet = KWallet::Wallet::openWallet( name );
+ wallet = TDEWallet::Wallet::openWallet( name );
}
if( wallet == NULL )
{
- KMessageBox::error( NULL, i18n( "Could not open KWallet." ) );
+ KMessageBox::error( NULL, i18n( "Could not open TDEWallet." ) );
return TQString::null;
}
@@ -119,7 +119,7 @@ TQString KWalletAccess::getPassword( const TQString & account )
bool setFolderSuccess = wallet->setFolder( "KShowmail" );
if( !setFolderSuccess )
{
- KMessageBox::error( NULL, i18n( "Could not open folder for KShowmail in KWallet." ) );
+ KMessageBox::error( NULL, i18n( "Could not open folder for KShowmail in TDEWallet." ) );
return TQString::null;
}
@@ -129,7 +129,7 @@ TQString KWalletAccess::getPassword( const TQString & account )
int readPasswordSuccess = wallet->readPassword( account, password );
if( readPasswordSuccess != 0 )
{
- KMessageBox::error( NULL, i18n( "Could not get password of account %1 from KWallet." ).arg( account) );
+ KMessageBox::error( NULL, i18n( "Could not get password of account %1 from TDEWallet." ).arg( account) );
return TQString::null;
}
diff --git a/kshowmail/tdewalletaccess.h b/kshowmail/tdewalletaccess.h
index 905abd9..3bc68d8 100644
--- a/kshowmail/tdewalletaccess.h
+++ b/kshowmail/tdewalletaccess.h
@@ -19,14 +19,14 @@
#include <tdelocale.h>
/**
* @brief Provides routines to save and read passwords using KWallet.
* @author Ulrich Weigelt <ulrich.weigelt@gmx.de>
*/
-namespace KWalletAccess
+namespace TDEWalletAccess
{
/**
* Saves the given password into KWallet.
* @param account account name
* @param password the password
* @return TRUE - password successfully saved
@@ -37,7 +37,7 @@ namespace KWalletAccess
/**
* Returns the password of the given account.
* @param account account name
* @return the password or TQString::null, if the sought password is not stored in KWallet.
*/
TQString getPassword( const TQString& account );
}
@@ -19,14 +19,14 @@
#include <tdelocale.h>
/**
- * @brief Provides routines to save and read passwords using KWallet.
+ * @brief Provides routines to save and read passwords using TDEWallet.
* @author Ulrich Weigelt <ulrich.weigelt@gmx.de>
*/
@@ -19,14 +19,14 @@
{
/**
- * Saves the given password into KWallet.
+ * Saves the given password into TDEWallet.
* @param account account name
* @param password the password
@@ -37,7 +37,7 @@ namespace KWalletAccess
* Returns the password of the given account.
* @param account account name
- * @return the password or TQString::null, if the sought password is not stored in KWallet.
+ * @return the password or TQString::null, if the sought password is not stored in TDEWallet.
*/
TQString getPassword( const TQString& account );